some project
============

1.0.6 (today)
+++++++++++++

* some very long and sophisticated message, which is too long to fit 79
  characters
* next message, which also is very long, but should fit into 79 characters aaaa
* let just say Lorem ipsum dolor sit amet consectetur adipisicing elit, sed do
  eiusmod tempor incididunt ut labore et dolore magna aliqua. Ut enim ad minim
  veniam, quis nostrud exercitation ullamco

1.0.5 (2014-04-06)
++++++++++++++++++

* some change
* another change
